==> haskell-th-reify-many-0.1.10-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-reify-many
version:              0.1.10
visibility:           public
id:                   th-reify-many-0.1.10-9l5NjsPKUSQCXfEDksc7cr
key:                  th-reify-many-0.1.10-9l5NjsPKUSQCXfEDksc7cr
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  83bbfdbced19c7e9943fae6e70bfd0ba
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-reify-many-0.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-reify-many-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-reify-many
hs-libraries:         HSth-reify-many-0.1.10-9l5NjsPKUSQCXfEDksc7cr
depends:
    base-4.15.1.0 containers-0.6.4.1 mtl-2.2.2
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q template-haskell-2.17.0.0
    th-expand-syns-0.4.10.0-5Fqj9ioWN9c9kvAleK1Zm2

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.10-85-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 th-reify-many
version:              0.1.10
visibility:           public
id:                   th-reify-many-0.1.10-4apD8UZLiu9HEPMNYEHra3
key:                  th-reify-many-0.1.10-4apD8UZLiu9HEPMNYEHra3
license:              BSD-3-Clause
maintainer:           Michael Sloan <mgsloan at gmail>
author:               Michael Sloan
stability:            Experimental
homepage:             http://github.com/mgsloan/th-reify-many
synopsis:             Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.

category:             Template Haskell
abi:                  63491b07ee13b9e2a9fa0cc763178dd7
exposed:              True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal

import-dirs:          /usr/lib/ghc-9.0.2/site-local/th-reify-many-0.1.10
library-dirs:         /usr/lib/ghc-9.0.2/site-local/th-reify-many-0.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-reify-many
hs-libraries:         HSth-reify-many-0.1.10-4apD8UZLiu9HEPMNYEHra3
depends:
    base-4.15.1.0 containers-0.6.4.1 mtl-2.2.2
    safe-0.3.19-2aVM1fCfxX88jnlVeNbd8Q template-haskell-2.17.0.0
    th-expand-syns-0.4.11.0-971nM5buyLKINUL1eCJZtq

haddock-interfaces:
    /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock

haddock-html:         /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
